Group: System/Libraries
# BEGIN SourceDeps(oneline):
BuildRequires(pre): rpm-macros-fedora-compat
BuildRequires: elektra-devel gcc-c++ libdiscount-devel python-devel
# END SourceDeps(oneline)
Name:           elektra
Version:        0.8.12
Release:        alt1_4
Summary:        A key/value pair database to store software configurations
License:        BSD
URL:            http://www.libelektra.org/
Source0:        http://www.libelektra.org/ftp/elektra/releases/elektra-%{version}.tar.gz
BuildRequires: boost-devel boost-devel-headers boost-filesystem-devel boost-wave-devel boost-graph-parallel-devel boost-math-devel boost-mpi-devel boost-program_options-devel boost-signals-devel boost-intrusive-devel boost-asio-devel
BuildRequires: ctest cmake
BuildRequires:  db4-devel
BuildRequires:  docbook-style-xsl
BuildRequires:  doxygen
BuildRequires:  gawk
BuildRequires:  libGConf-devel
BuildRequires:  gettext-devel
BuildRequires:  libxml2-devel
BuildRequires: xsltproc libxslt
BuildRequires:  liblua5-devel
BuildRequires:  python3-devel
BuildRequires:  swig
BuildRequires:  libyajl-devel
Source44: import.info
Patch33: elektra-0.8.12-alt-as-needed.patch

%description
Elektra provides a universal and secure framework to store configuration
parameters in a global, hierarchical key database. The core is a small
library implemented in C. The plugin-based framework fulfills many
configuration-related tasks to avoid any unnecessary code duplication
across applications while it still allows the core to stay without any
external dependency. Elektra abstracts from cross-platform-related issues
with an consistent API, and allows applications to be aware of other
applications' configurations, leveraging easy application integration.

== Facts and Features ==

* Elektra uses the BSD licence.
* Elektra implements an API to fully access a global key database.
* Elektra supports mounting of existing configuration files into the global 
key database.
* Elektra has dozens of Plugins that make it possible to have a tiny core, 
but still support all features.
* Elektra can import and export configuration files in any supported format.
* Elektra is able to log and notify other software on any configuration 
changes using Dbus and Journald.
* Elektra can improve robustness by rejecting invalid configuration via type 
checking, regex and more.
* Elektra provides different mechanisms to locate configuration files.
* Elektra supports different ways to escape and encode content of 
configuration files.
* Elektra is multi-process safe and can be used in multi-threaded programs.
* Elektra (except for some plugins) is portable and completely written in 
Ansi-C99.
* Elektra (except for some plugins) has no external dependency.
* Elektra is suitable for embedded systems and early boot stage programs.
* Elektra supports comments and other non-configuration information by meta 
data.
* Elektra provides many powerful Bindings to avoid low-level access code.
* Elektra provides powerful Code Generation Techniques for Configuration 
Access.

This package also contains a Berkeley DB backend for Elektra, to let 
Elektra use Berkeley DB databases to store its keys and daemon which can
be used as a proxy for access to the keys.

%package        devel
Group: Development/Other
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    devel
This package contains libraries and header files for
developing elektrified applications.

%prep
%setup -q
#%patch33 -p1

%build
mkdir build && cd $_
%{fedora_cmake} ..                                            \
    -DPLUGINS=ALL                                    \
    -DTOOLS=ALL                                      \
    -DBUILD_SHARED=ON                                \
    -DBUILD_STATIC=OFF                               \
    -DBUILD_TESTING=ON                               \
    -DBUILD_SWIG=ON                                  \
    -DBUILD_SWIG_LUA=ON                              \
    -DBUILD_SWIG_PYTHON3=ON                          \
    -DPython_ADDITIONAL_VERSIONS=%{__python3_version}  \
    -DBUILD_EXAMPLES=OFF                             \
    -DTARGET_CMAKE_FOLDER=%{_libdir}/cmake           \
    -DTARGET_DOCUMENTATION_FOLDER=%{_datadir}

# Parallel build seems to cause unpredictable failures?
make #%{?_smp_mflags}

%install
%makeinstall_std -C build

mkdir -p %{buildroot}%{_mandir}/man3/ %{buildroot}%{_sysconfdir}/profile.d/
# file in profile.d is sourced, remove shebang and execute bits.
install -p scripts/elektraenv.sh %{buildroot}%{_sysconfdir}/profile.d/
sed -i -e 's;#!/bin/sh;;' %{buildroot}%{_sysconfdir}/profile.d/elektraenv.sh

# This stuff is all for the test suite, which we aren't really interested in.
rm -f %{buildroot}%{_libdir}/elektra/tool_exec/{run_all,check*,test*}
rm -rf %{buildroot}%{_datadir}/elektra
rm -f %{buildroot}%{_bindir}/kdb-full
# per Debian package, libelektra-full is only used for the tests.
rm -f %{buildroot}%{_libdir}/libelektra-full*
rm -f %{buildroot}%{_libdir}/libelektratools-full*

rm -frv %{buildroot}%{_datadir}/html
# broken symlinks
find -L $RPM_BUILD_ROOT%{_libdir}/elektra -type l -delete

%check
# Test #36~42 failed because of lack of root permission.
make test -C build || true

%post
kdb set -t dir system/sw > /dev/null 2>&1
kdb set system/sw/kdb/schemapath "%{_datadir}/sgml/elektra/elektra.xsd" > /dev/null 2>&1 || :

%files
%doc doc/COPYING
%{_bindir}/kdb
%{_libdir}/elektra
%{_libdir}/libelektra.so.4*
%{_libdir}/libelektra.so.%{version}
%{_libdir}/libelektratools.so
# Do not use (noreplace) for this config file.
%config %{_sysconfdir}/profile.d/*.sh
%{_sysconfdir}/bash_completion.d
%{_sysconfdir}/profile.d/kdb
#{_datadir}/sgml/elektra/

%files devel
%doc README.md
%doc doc/AUTHORS doc/CODING.md doc/DESIGN.md doc/NEWS.md doc/SECURITY.md
%doc examples/
%dir %{_libdir}/cmake
%{_docdir}/elektra-api/
%{_libdir}/cmake/FindElektra.cmake
%{_includedir}/elektra/
%{_libdir}/libelektra.so
%{_libdir}/pkgconfig/elektra.pc
%{_mandir}/man3/*.3*

%changelog
