Group: Sound
# BEGIN SourceDeps(oneline):
BuildRequires(pre): rpm-macros-cmake rpm-macros-fedora-compat
BuildRequires: /usr/bin/desktop-file-validate boost-devel
# END SourceDeps(oneline)
# see https://bugzilla.altlinux.org/show_bug.cgi?id=10382
%define _localstatedir %{_var}
Name:           harmonyseq
Summary:        MIDI sequencer designed for live performances
Version:        0.17
Release:        alt1_2

# The entire source is GPLv3+ except the .metainfo.xml file and the contents of
# images/ which are CC0.
License:        GPLv3+ and CC0
URL:            https://harmonyseq.wordpress.com/
%global srcname harmonySEQ
%global forgeurl https://github.com/rafalcieslak/%{srcname}/
Source0:        %{forgeurl}/archive/v%{version}/%{srcname}-%{version}.tar.gz

# https://github.com/rafalcieslak/harmonySEQ/issues/7
Patch0:         %{name}-0.17-missing-include.patch
# https://github.com/rafalcieslak/harmonySEQ/issues/5
# https://github.com/rafalcieslak/harmonySEQ/issues/6
# https://github.com/rafalcieslak/harmonySEQ/pull/8
Patch1:         %{name}-0.17-pr-8-metadata-improvements.patch

BuildRequires:  gcc-c++
BuildRequires:  ctest cmake
# The 'UNIX Makefiles' backend would have worked fine too; we choose ninja.
BuildRequires:  ninja-build python3-module-ninja_syntax

#BuildRequires:  gettext-devel
BuildRequires:  pkgconfig(gtkmm-3.0)
BuildRequires:  pkgconfig(glibmm-2.4)
BuildRequires:  pkgconfig(liblo)
BuildRequires:  libalsa-devel
BuildRequires:  boost-complete

BuildRequires:  desktop-file-utils
BuildRequires:  libappstream-glib

# For %%{_datadir}/share/mime/packages
Requires:       shared-mime-info

Provides:       %{name}-doc = %{version}-%{release}
Conflicts:      %{name}-doc = 0.17-1
Obsoletes:      %{name}-doc < 0.17-1

%global app_id org.cielak.%{name}
Source44: import.info

%description
A MIDI software sequencer designed for live performances and jams.

%{srcname} operates a number of synchronized sequencers, each with its own
pattern, repeating looped melodies of different length, duration and MIDI
channel.

Main features include:

  a.. support for complex polyrhythms
  a.. multi-pattern configuration for each sequencer
  a.. customizable action triggers - exceptionally useful for live performances
  a.. chord management system which allows to easily organize melodies that sound
    great together
  a.. support for sequencing MIDI control messages
  a.. an easy-to-use yet powerful interface, with a rich piano-roll pattern
    editor

As for now %{srcname} works on Linux only. It uses ALSA (asound) library, and
GTKmm for graphical interface.

No official user documentation exists at the moment, but you can refer to UI
tooltips - nearly everything has a detailed explanation.

More information can be found on the projecta.'s (dated) website:
https://harmonyseq.wordpress.com


%package doc
Group: Sound
Summary:        Documentation and examples for %{srcname}
License:        GPLv3+
BuildArch:      noarch

%description doc
Documentation and examples for %{srcname}.


%prep
%setup -q -n %{srcname}-%{version}
%patch0 -p1
%patch1 -p1



%build
# We need the preprocessor macro RELEASE set so that src/main.cpp looks for
# resoures in the installation path (DATA_PATH). Normally this is set with
# -DCMAKE_BUILD_TYPE=Release, but this also asks to strip debugging symbols,
# which we do not want. Setting -DCMAKE_BUILD_TYPE=RelWithDebInfo does not set
# the preprocessor macro. Instead, we set it manually:

CFLAGS="${CFLAGS} -DRELEASE"
CXXFLAGS="${CXXFLAGS} -DRELEASE"

%{fedora_v2_cmake} -DCMAKE_BUILD_TYPE=RelWithDebInfo -GNinja
%fedora_v2_cmake_build


%install
%fedora_v2_cmake_install

# Not a standard size for GNOME icons, so gnome-icon-theme does not have the
# directories:
rm -rvf '%{buildroot}%{_datadir}/icons/gnome/192x192'


%check
desktop-file-validate %{buildroot}/%{_datadir}/applications/%{app_id}.desktop
appstream-util validate-relax --nonet \
    %{buildroot}%{_metainfodir}/%{app_id}.metainfo.xml


%files
%doc --no-dereference LICENSE
%doc CHANGELOG.md
%doc README.md
%doc examples

%{_bindir}/%{srcname}
%{_mandir}/man1/%{srcname}.1*

%{_datadir}/%{srcname}

%{_datadir}/applications/%{app_id}.desktop
%{_metainfodir}/%{app_id}.metainfo.xml

%{_datadir}/mime/packages/%{name}-mime.xml


%changelog
